Small update to the patch: change doxygen comment to match new argument name.

Regards,
Alexey.

On Tuesday, August 10, 2010 02:53:50 pm Alexey Neyman wrote:
> Hi all,
> 
> Looks like the binding for svn_fs_paths_changed2() incorrectly specifies
> the type of structures contained in the hash it returns: the following
> code
> 
> s = fs.paths_changed2(rev_root, pool)
> for i in s:
>   sys.stderr.write("%s = %s\n" % (i, repr(s)))
> 
> indicates that bindings assume the hash to contain svn_fs_path_change_t
> structures, not svn_fs_path_change2_t as it should (it's the difference
> between fs.paths_changed() and fs.paths_changed2(), actually).
> 
> The attached patch fixes this issue.
> 
> Regards,
> Alexey.
Index: subversion/bindings/swig/svn_fs.i
===================================================================
--- subversion/bindings/swig/svn_fs.i	(revision 980930)
+++ subversion/bindings/swig/svn_fs.i	(working copy)
@@ -62,6 +62,7 @@
 
 %hash_argout_typemap(entries_p, svn_fs_dirent_t *)
 %hash_argout_typemap(changed_paths_p, svn_fs_path_change_t *)
+%hash_argout_typemap(changed_paths_p2, svn_fs_path_change2_t *)
 
 #ifndef SWIGPERL
 %callback_typemap(svn_fs_get_locks_callback_t get_locks_func,

Reply via email to
Index: subversion/include/svn_fs.h
===================================================================
--- subversion/include/svn_fs.h	(revision 980930)
+++ subversion/include/svn_fs.h	(working copy)
@@ -1154,7 +1154,7 @@
 
 /** Determine what has changed under a @a root.
  *
  * Allocate and return a hash @a *changed_paths_p containing descriptions
  * of the paths changed under @a root.  The hash is keyed with
  * <tt>const char *</tt> paths, and has #svn_fs_path_change2_t * values.
  *
@@ -1169,7 +1169,7 @@
  * @since New in 1.6.
  */
 svn_error_t *
-svn_fs_paths_changed2(apr_hash_t **changed_paths_p,
+svn_fs_paths_changed2(apr_hash_t **changed_paths_p2,
                       svn_fs_root_t *root,
                       apr_pool_t *pool);
 
@@ -1154,7 +1154,7 @@
 /** Determine what has changed under a @a root.
  *
- * Allocate and return a hash @a *changed_paths_p containing descriptions
+ * Allocate and return a hash @a *changed_paths_p2 containing descriptions
  * of the paths changed under @a root.  The hash is keyed with
  * <tt>const char *</tt> paths, and has #svn_fs_path_change2_t * values.